# Generated by Django 4.2.2 on 2023-07-03 18:00

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0011_cjkcmspage_related_classifier_term_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="analyticssettings",
            name="ga_tracking_id",
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="matomo_disable_cookies",
            field=models.BooleanField(
                default=False,
                help_text="Disable Matomo cookies. Useful for GDPR compliance.",
                verbose_name="Disable Matomo Cookies",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="matomo_hostname",
            field=models.CharField(
                blank=True,
                help_text="Matomo hostname (e.g. https://tracker.com). Without trailing slash.",
                max_length=128,
                verbose_name="Hostname (including http(s)://)",
            ),
        ),
        migrations.AddField(
            model_name="analyticssettings",
            name="matomo_site_id",
            field=models.IntegerField(
                blank=True,
                help_text="Numeric site id from Matomo website configuration.",
                null=True,
                verbose_name="Site ID",
            ),
        ),
    ]
