# Generated by Django 4.2.4 on 2023-08-19 16:03

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("cjkcms", "0013_socialmediasettings_location"),
    ]

    operations = [
        migrations.AddField(
            model_name="navbar",
            name="alignment",
            field=models.CharField(
                blank=True,
                choices=[
                    ("me-auto", "Left (me-auto)"),
                    ("ms-auto", "Right (ms-auto)"),
                    ("mx-auto", "Center (mx-auto)"),
                    ("", "None"),
                ],
                default="me-auto",
                help_text="Force navbar alignment",
                max_length=32,
                verbose_name="Alignment",
            ),
        ),
    ]
