{% extends 'cjkcms/pages/base.html' %}

{% block navbar %}
    {% include 'cjkcms/snippets/navbar.html' %}
{% endblock %}

{% block actionbar %}
    {% include 'cjkcms/snippets/actionbar.html' %}
{% endblock %}

{% block footer %}
{% include 'cjkcms/snippets/footer.html' %}
{% endblock %}