{% load wagtailsettings_tags %}
<noscript><p><img src="{{settings.cjkcms.AnalyticsSettings.matomo_hostname}}/matomo.php?rec=1&idsite={{settings.cjkcms.AnalyticsSettings.matomo_site_id}}" style="border:0;" alt="" /></p></noscript>
